# This file was auto-generated by Fern from our API Definition.

import typing

BotConversationMessageType = typing.Union[
    typing.Literal["BOT_RESPONSE", "BOT_SUGGESTION", "ACTION_RESPONSE"], typing.Any
]
