# This file was auto-generated by Fern from our API Definition.

from ...core.pydantic_utilities import UniversalBaseModel
import typing_extensions
import typing
from ...commons.types.entity_id_base import EntityIdBase
from ...core.serialization import FieldMetadata
import pydantic
from ...core.pydantic_utilities import IS_PYDANTIC_V2


class GenerateMavenSuggestionsRequest(UniversalBaseModel):
    conversation_message_ids: typing_extensions.Annotated[
        typing.List[EntityIdBase], FieldMetadata(alias="conversationMessageIds")
    ] = pydantic.Field()
    """
    The message ids to generate a suggested response for. One suggestion will be generated for each message id.
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
